<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 */
function optionsframework_option_name() {
	// Change this to use your theme slug
	return 'options-framework-theme';
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'theme-textdomain'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Test data
	$test_array = array(
		'one' => __( 'One', 'theme-textdomain' ),
		'two' => __( 'Two', 'theme-textdomain' ),
		'three' => __( 'Three', 'theme-textdomain' ),
		'four' => __( 'Four', 'theme-textdomain' ),
		'five' => __( 'Five', 'theme-textdomain' )
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __( 'French Toast', 'theme-textdomain' ),
		'two' => __( 'Pancake', 'theme-textdomain' ),
		'three' => __( 'Omelette', 'theme-textdomain' ),
		'four' => __( 'Crepe', 'theme-textdomain' ),
		'five' => __( 'Waffle', 'theme-textdomain' )
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages( 'sort_column=post_parent,menu_order' );
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

	$options[] = array(
		'name' => __( 'Header Settings', 'theme-textdomain' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Header Logo', 'theme-textdomain' ),
		'desc' => __( 'Add header logo to the site', 'theme-textdomain' ),
		'id' => 'header_logo',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => __( 'Background Settings', 'theme-textdomain' ),
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( 'Background Image', 'theme-textdomain' ),
		'desc' => __( 'Add Background', 'theme-textdomain' ),
		'id' => 'services_background_img',
		'type' => 'upload'
	);
	$options[] = array(
		'name' => __( 'Home Page Testimonial Image', 'theme-textdomain' ),
		'desc' => __( 'Add Home Page Testimonial Background Image', 'theme-textdomain' ),
		'id' => 'testimonial_background_img',
		'type' => 'upload'
	);
	$options[] = array(
		'name' => __( 'Footer And Contact us Page Settings', 'theme-textdomain' ),
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( 'Facebook Image', 'theme-textdomain' ),
		'desc' => __( 'Add Footer Facebook', 'theme-textdomain' ),
		'id' => 'facebook_img',
		'type' => 'upload'
	);
	$options[] = array(
		'name' => __( 'Facebook URL', 'theme-textdomain' ),
		'desc' => __( 'Add Footer Facebook url', 'theme-textdomain' ),
		'id' => 'footer_fb_url',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Google Plus Image', 'theme-textdomain' ),
		'desc' => __( 'Add Footer Google Plus Image', 'theme-textdomain' ),
		'id' => 'footer_google_plus_img',
		'type' => 'upload'
	);
	$options[] = array(
		'name' => __( 'Google Plus URL', 'theme-textdomain' ),
		'desc' => __( 'Add Google plus url', 'theme-textdomain' ),
		'id' => 'footer_gp_url',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Linked In Image', 'theme-textdomain' ),
		'desc' => __( 'Add Footer Linkedin image', 'theme-textdomain' ),
		'id' => 'Footer_linkedin_img',
		'type' => 'upload'
	);
	$options[] = array(
		'name' => __( 'Linked In URL', 'theme-textdomain' ),
		'desc' => __( 'Add Linkedin url', 'theme-textdomain' ),
		'id' => 'footer_linkedin_url',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Twitter Image', 'theme-textdomain' ),
		'desc' => __( 'Add Footer twitter image', 'theme-textdomain' ),
		'id' => 'Footer_twitter_img',
		'type' => 'upload'
	);
	$options[] = array(
		'name' => __( 'Twitter URL', 'theme-textdomain' ),
		'desc' => __( 'Add Twitter url', 'theme-textdomain' ),
		'id' => 'footer_twitter_url',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Mumbai Office Address', 'theme-textdomain' ),
		'desc' => __( 'Add Mumbai office address', 'theme-textdomain' ),
		'id' => 'mumbai_office_addr',
		'type' => 'textarea'
	);
	$options[] = array(
		'name' => __( 'Mumbai office Phone 1', 'theme-textdomain' ),
		'desc' => __( 'Add Mumbai Phone Number 1', 'theme-textdomain' ),
		'id' => 'mumbai_off_phone_1',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Mumbai office Phone 2', 'theme-textdomain' ),
		'desc' => __( 'Add Mumbai Phone Number 2', 'theme-textdomain' ),
		'id' => 'mumbai_off_phone_2',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Mumbai office Phone 3', 'theme-textdomain' ),
		'desc' => __( 'Add Mumbai Phone Number 3', 'theme-textdomain' ),
		'id' => 'mumbai_off_phone_3',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Mumbai office Fax', 'theme-textdomain' ),
		'desc' => __( 'Add Mumbai Fax Number ', 'theme-textdomain' ),
		'id' => 'mumbai_off_fax',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Mumbai office Email', 'theme-textdomain' ),
		'desc' => __( 'Add Mumbai Email ID', 'theme-textdomain' ),
		'id' => 'mumbai_off_email',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trivandrum Office Address', 'theme-textdomain' ),
		'desc' => __( 'Add Trivandrum office address', 'theme-textdomain' ),
		'id' => 'tvm_office_addr',
		'type' => 'textarea'
	);
	$options[] = array(
		'name' => __( 'Trivandrum office Phone 1', 'theme-textdomain' ),
		'desc' => __( 'Add Trivandrum Phone Number 1', 'theme-textdomain' ),
		'id' => 'tvm_off_phone_1',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trivandrum office Phone 2', 'theme-textdomain' ),
		'desc' => __( 'Add Trivandrum Phone Number 2', 'theme-textdomain' ),
		'id' => 'tvm_off_phone_2',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trivandrum office Phone 3', 'theme-textdomain' ),
		'desc' => __( 'Add Trivandrum Phone Number 3', 'theme-textdomain' ),
		'id' => 'tvm_off_phone_3',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trivandrum office Email', 'theme-textdomain' ),
		'desc' => __( 'Add Trivandrum Email ID', 'theme-textdomain' ),
		'id' => 'tvm_off_email',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trichur Office Address', 'theme-textdomain' ),
		'desc' => __( 'Add Trichur office address', 'theme-textdomain' ),
		'id' => 'tch_office_addr',
		'type' => 'textarea'
	);
	$options[] = array(
		'name' => __( 'Trichur office Phone 1', 'theme-textdomain' ),
		'desc' => __( 'Add Trichur Phone Number 1', 'theme-textdomain' ),
		'id' => 'tch_off_phone_1',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trichur office Phone 2', 'theme-textdomain' ),
		'desc' => __( 'Add Trichur Phone Number 2', 'theme-textdomain' ),
		'id' => 'tch_off_phone_2',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trichur office Phone 3', 'theme-textdomain' ),
		'desc' => __( 'Add Trichur Phone Number 3', 'theme-textdomain' ),
		'id' => 'tch_off_phone_3',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Trichur office Email', 'theme-textdomain' ),
		'desc' => __( 'Add Trichur Email ID', 'theme-textdomain' ),
		'id' => 'tch_off_email',
		'type' => 'text'
	);
		$options[] = array(
		'name' => __( 'Cochin Office Address', 'theme-textdomain' ),
		'desc' => __( 'Add Cochin office address', 'theme-textdomain' ),
		'id' => 'coc_office_addr',
		'type' => 'textarea'
	);
	$options[] = array(
		'name' => __( 'Cochin office Phone 1', 'theme-textdomain' ),
		'desc' => __( 'Add Cochin Phone Number 1', 'theme-textdomain' ),
		'id' => 'coc_off_phone_1',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Cochin office Phone 2', 'theme-textdomain' ),
		'desc' => __( 'Add Cochin Phone Number 2', 'theme-textdomain' ),
		'id' => 'coc_off_phone_2',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Cochin office Phone 3', 'theme-textdomain' ),
		'desc' => __( 'Add Cochin Phone Number 3', 'theme-textdomain' ),
		'id' => 'coc_off_phone_3',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Cochin office Email', 'theme-textdomain' ),
		'desc' => __( 'Add Cochin Email ID', 'theme-textdomain' ),
		'id' => 'coc_off_email',
		'type' => 'text'
	);
	$options[] = array(
		'name' => __( 'Footer Google Map URL', 'theme-textdomain' ),
		'desc' => __( 'Add Footer Goodgle Map URL', 'theme-textdomain' ),
		'id' => 'google_map_url',
		'type' => 'text'
	);
	/*$options[] = array(
		'name' => __( 'Input Text', 'theme-textdomain' ),
		'desc' => __( 'A text input field.', 'theme-textdomain' ),
		'id' => 'example_text',
		'std' => 'Default Value',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Input with Placeholder', 'theme-textdomain' ),
		'desc' => __( 'A text input field with an HTML5 placeholder.', 'theme-textdomain' ),
		'id' => 'example_placeholder',
		'placeholder' => 'Placeholder',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Textarea', 'theme-textdomain' ),
		'desc' => __( 'Textarea description.', 'theme-textdomain' ),
		'id' => 'example_textarea',
		'std' => 'Default Text',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Input Select Small', 'theme-textdomain' ),
		'desc' => __( 'Small Select Box.', 'theme-textdomain' ),
		'id' => 'example_select',
		'std' => 'three',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $test_array
	);

	$options[] = array(
		'name' => __( 'Input Select Wide', 'theme-textdomain' ),
		'desc' => __( 'A wider select box.', 'theme-textdomain' ),
		'id' => 'example_select_wide',
		'std' => 'two',
		'type' => 'select',
		'options' => $test_array
	);

	if ( $options_categories ) {
		$options[] = array(
			'name' => __( 'Select a Category', 'theme-textdomain' ),
			'desc' => __( 'Passed an array of categories with cat_ID and cat_name', 'theme-textdomain' ),
			'id' => 'example_select_categories',
			'type' => 'select',
			'options' => $options_categories
		);
	}

	if ( $options_tags ) {
		$options[] = array(
			'name' => __( 'Select a Tag', 'options_check' ),
			'desc' => __( 'Passed an array of tags with term_id and term_name', 'options_check' ),
			'id' => 'example_select_tags',
			'type' => 'select',
			'options' => $options_tags
		);
	}

	$options[] = array(
		'name' => __( 'Select a Page', 'theme-textdomain' ),
		'desc' => __( 'Passed an pages with ID and post_title', 'theme-textdomain' ),
		'id' => 'example_select_pages',
		'type' => 'select',
		'options' => $options_pages
	);

	$options[] = array(
		'name' => __( 'Input Radio (one)', 'theme-textdomain' ),
		'desc' => __( 'Radio select with default options "one".', 'theme-textdomain' ),
		'id' => 'example_radio',
		'std' => 'one',
		'type' => 'radio',
		'options' => $test_array
	);

	$options[] = array(
		'name' => __( 'Example Info', 'theme-textdomain' ),
		'desc' => __( 'This is just some example information you can put in the panel.', 'theme-textdomain' ),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'Input Checkbox', 'theme-textdomain' ),
		'desc' => __( 'Example checkbox, defaults to true.', 'theme-textdomain' ),
		'id' => 'example_checkbox',
		'std' => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Advanced Settings', 'theme-textdomain' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Check to Show a Hidden Text Input', 'theme-textdomain' ),
		'desc' => __( 'Click here and see what happens.', 'theme-textdomain' ),
		'id' => 'example_showhidden',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Hidden Text Input', 'theme-textdomain' ),
		'desc' => __( 'This option is hidden unless activated by a checkbox click.', 'theme-textdomain' ),
		'id' => 'example_text_hidden',
		'std' => 'Hello',
		'class' => 'hidden',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Uploader Test', 'theme-textdomain' ),
		'desc' => __( 'This creates a full size uploader that previews the image.', 'theme-textdomain' ),
		'id' => 'example_uploader',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => "Example Image Selector",
		'desc' => "Images for layout.",
		'id' => "example_images",
		'std' => "2c-l-fixed",
		'type' => "images",
		'options' => array(
			'1col-fixed' => $imagepath . '1col.png',
			'2c-l-fixed' => $imagepath . '2cl.png',
			'2c-r-fixed' => $imagepath . '2cr.png'
		)
	);

	$options[] = array(
		'name' =>  __( 'Example Background', 'theme-textdomain' ),
		'desc' => __( 'Change the background CSS.', 'theme-textdomain' ),
		'id' => 'example_background',
		'std' => $background_defaults,
		'type' => 'background'
	);

	$options[] = array(
		'name' => __( 'Multicheck', 'theme-textdomain' ),
		'desc' => __( 'Multicheck description.', 'theme-textdomain' ),
		'id' => 'example_multicheck',
		'std' => $multicheck_defaults, // These items get checked by default
		'type' => 'multicheck',
		'options' => $multicheck_array
	);

	$options[] = array(
		'name' => __( 'Colorpicker', 'theme-textdomain' ),
		'desc' => __( 'No color selected by default.', 'theme-textdomain' ),
		'id' => 'example_colorpicker',
		'std' => '',
		'type' => 'color'
	);

	$options[] = array( 'name' => __( 'Typography', 'theme-textdomain' ),
		'desc' => __( 'Example typography.', 'theme-textdomain' ),
		'id' => "example_typography",
		'std' => $typography_defaults,
		'type' => 'typography'
	);

	$options[] = array(
		'name' => __( 'Custom Typography', 'theme-textdomain' ),
		'desc' => __( 'Custom typography options.', 'theme-textdomain' ),
		'id' => "custom_typography",
		'std' => $typography_defaults,
		'type' => 'typography',
		'options' => $typography_options
	);

	$options[] = array(
		'name' => __( 'Text Editor', 'theme-textdomain' ),
		'type' => 'heading'
	);

	/**
	 * For $settings options see:
	 * http://codex.wordpress.org/Function_Reference/wp_editor
	 *
	 * 'media_buttons' are not supported as there is no post to attach items to
	 * 'textarea_name' is set by the 'id' you choose
	 */

	/*$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress,wplink' )
	);

	$options[] = array(
		'name' => __( 'Default Text Editor', 'theme-textdomain' ),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'theme-textdomain' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'example_editor',
		'type' => 'editor',
		'settings' => $wp_editor_settings
	);*/

	return $options;
}